@@ -1307,6 +1307,14 @@ void showVariables(FILE *fp)
 }
 
 /*********************************************************************************/
+static void genMyFloatCode(void)
+{
+  fprintf(outfile, "%s\n", my_float_api_macros);
+  fprintf(outfile, "%s\n", MY_FLOAT_FUN_MACRO);
+//  if (genMyBlas) // move it to genMyJetCode to use auxiliary MY_FLOAT
+  fprintf(outfile, "\n");
+}
+
 void genCode(void)
 {
   int i,j, tmpcnt;
@@ -1315,15 +1323,18 @@ void genCode(void)
   else { fprintf(outfile, "#include \"%s\"\n\n", header_name);}
   if (genMain)   { genMainCode(); }
   if (genStep)   { genStepCode();}
-  if (genMyJet)  { genMyJetCode(); }
+  genMyFloatCode();
+  if (genMyCoef) { genMyCoefCode(); }
+  if (genMyCloud) { genMyCloudCode(); }
+  else if (genMyJet)  { genMyJetCode(); }
   if (genJet == 0) return;
 
   fprintf(outfile,"/***********************************************************************\n");
   fprintf(outfile," *\n");
   fprintf(outfile," * Procedure generated by the TAYLOR translator. Do not edit!\n");
   fprintf(outfile," *\n");
-  fprintf(outfile," * It needs the header file 'taylor.h' to compile.\n");
-  fprintf(outfile," * Run taylor with the -header -o taylor.h option to generate a sample 'taylor.h'\n\n");
+  fprintf(outfile," * It needs the header file '%s' to compile.\n", header_name);
+  fprintf(outfile," * Run taylor with the -header -o %s option to generate a sample '%s'\n\n", header_name, header_name);
   fprintf(outfile," * Translation info is at the end of this file.\n");
   fprintf(outfile," * %s\n", versionString);
   fprintf(outfile," ***********************************************************************/\n\n");
