@@ -35,6 +35,11 @@ ExternVar externVars = NULL;
 Node      *jetVars = NULL;
 int       njetVars = 0;
 int       jetVarSpace = 0;
+
+Node      *cloudVars = NULL;
+int       ncloudVars = 0;
+int       cloudVarSpace = 0;
+
 int       nexterns = 0;
 int       externSpace = 0;
 int       neqns     = 0;
@@ -581,6 +586,30 @@ void checkVars()
 	}
     }
 }
+
+/*************************************************************
+ *
+ *  make sure function names are lementary functions. 11/12/24
+ */
+void checkCallFunctionName(Node expr) {
+    Node def = NODE_LEFT(expr);
+    char *ptr = ID_NAME(def);
+    int i=0,ok = 0;
+    while(elemFunctions[i])
+      {
+        char *qtr = elemFunctions[i];
+        if( *ptr == *qtr && !strcmp(qtr, ptr))
+          {
+            ok = 1;
+            break;
+          }
+        i++;
+      }
+    if(!ok) {
+      fprintf(stderr, "Fatal Error: '%s' is not an elementary function in  '%s'\n", ID_NAME(def), NODE_INFO(expr));
+    }
+}
+
 /********************************************************
  *
  *  make sure all vars appeared in 'def' are defined.
@@ -625,6 +654,7 @@ void checkAllDefined(Node def, Node *badvar)
 	  checkAllDefined(NODE_LEFT(def), badvar);
 	  break;
 	case CALL_EXPR:
+          checkCallFunctionName(def);
 	  checkAllDefined(NODE_RIGHT(def), badvar);
 	  break;
         case IF_ELSE_EXPR:
@@ -1745,6 +1775,59 @@ int markAllVarsJet() {
 }
 // 20220609 end
 /*******************************************************************************/
+// 20230805
+void  record_cloud_var(Node var) {
+  if(cloudVarSpace == 0) {
+    cloudVars = (Node *)my_malloc(32 * sizeof(Node));
+    cloudVarSpace = 32;
+  } else if(ncloudVars+1 >= cloudVarSpace) {
+    cloudVars = (Node *)my_realloc(cloudVars, 2 * cloudVarSpace * sizeof(Node));
+    cloudVarSpace *= 2;
+  }
+  cloudVars[ncloudVars++] = var;
+}
+
+int markAllVarsCloud() {
+  int i;
+  for(i = 0; i < neqns; i++) {
+    Node var = equations[i].name;
+    if(var) {
+      SET_VAR_IS_CLOUD(var);
+      SET_VAR_IS_DECLARED_CLOUD(var);
+      record_cloud_var(var);      
+    }
+  }
+  num_cloud_vars = neqns;
+  return num_cloud_vars;
+}
+
+Node markCloud(Node var)
+{
+  if(var)
+    {
+      int code = NODE_CODE(var);
+      if(code != ID_NODE)
+        {
+          fprintf(stderr, "Internal Error in CLOUD declaration, Var is not an ID node.\n");
+          exit(5);
+        }
+      if(ID_IS_DEFINED(var))
+        {
+          fprintf(stderr, "Error in CLOUD declaration: symbol '%s' is already used as a local variable.\n", NODE_NAME(var));
+          exit(5);
+        }
+      SET_VAR_IS_CLOUD(var);
+      SET_VAR_IS_DECLARED_CLOUD(var);
+      //      ID_SINDEX(var) = ++state_jet_vars;
+      record_cloud_var(var);      
+      return(var);
+    }
+  return(NULL);
+}
+
+// 20230805
+/*******************************************************************************/
+
 
 Node markJetParameter(Node var)
 {
